import { IProduct, IOrder, IOrderLine, IOrderCoupon, IStringKeyRecord } from '@orderingstack/ordering-types';

interface OrderingstackAnalyticsConfig {
    platform: string;
    getKioskId?: () => string | undefined | null;
    getVenueId?: () => string | undefined | null;
    getOrderId?: () => string | undefined | null;
}
declare function orderingstackPlugin(config: OrderingstackAnalyticsConfig): {
    name: string;
    page: ({ payload }: {
        payload: any;
    }) => void;
    track: ({ payload }: {
        payload: any;
    }) => void;
    loaded: () => boolean;
};
/**
 * Extends google analytics plugin to reset userId & cookie.
 * USAGE Object.assign({}, originalGaPlugin, googleAnalyticsResetExtension)
 */
export declare const googleAnalyticsResetExtension: {
    reset: ({ config }: {
        config: any;
    }) => void;
};
declare function mapItemToGaItem(item: IProduct): GaPayloadItem;
declare function mapSelectedMenuToViewItemList(product: IProduct): {
    item_list_id: string;
    item_list_name: string | undefined;
    items: GaPayloadItem[] | undefined;
};
declare function couponToGaPromotion(coupon: IOrderCoupon): {
    coupon: string;
    promotion_name: string | undefined;
};
export interface GaPayloadItem {
    item_id: string;
    item_name?: string;
    location_id?: string;
    price?: number;
    quantity?: number;
    coupon?: string;
    promotion_name?: string;
    item_category?: string;
    item_category2?: string;
    item_category3?: string;
    item_category4?: string;
    item_category5?: string;
    item_extra?: IStringKeyRecord<string>;
    item_fiscal?: string;
}
declare function mapOrderToPayload(order: IOrder, coupons: IOrderCoupon[], currency: string, venue?: string): {
    currency: string;
    value: number;
    items: GaPayloadItem[];
};
declare function linesToGaCartItems(lines: IOrderLine | IOrderLine[], venue: string, coupons: IOrderCoupon[], quantity?: number): {
    value: number;
    items: GaPayloadItem[];
};
export declare const utils: {
    mapItemToGaItem: typeof mapItemToGaItem;
    mapSelectedMenuToViewItemList: typeof mapSelectedMenuToViewItemList;
    mapOrderToPayload: typeof mapOrderToPayload;
    linesToGaCartItems: typeof linesToGaCartItems;
    couponToGaPromotion: typeof couponToGaPromotion;
};
export default orderingstackPlugin;
//# sourceMappingURL=index.d.ts.map